Density, distribution function, quantile function and random generation for the Gumbel distribution (for maxima) with scale and location parameters equal to scale and location, respectively.
logical; if TRUE, probabilities p are given as log(p).
lower.tail
logical; if TRUE (default), probabilities are P[X <= x]<="" em="">,otherwise, P[X > x].=>
Value
dgumbel gives the density, pgumbel gives the distribution function, qgumbel gives the quantile function, and rgumbel generates random deviates.
Details
If X is a random variable distributed according to a Gumbel distribution, it has density
f(x) = 1/scale*exp(-(x-location)/scale-exp(-(x-location)/scale))
References
Coles, S. (2001) An introduction to statistical modeling of extreme values. Springer